@@ -63,12 +63,6 @@
 #define CLEANUP_STAT_PROXY	(1<<7)	/* Proxy reject */
 #define CLEANUP_STAT_DEFER	(1<<8)	/* Temporary reject */
 
- /*
-  * Non-cleanup errors that live in the same bitmask space, to centralize
-  * error handling.
-  */
-#define CLEANUP_STAT_BARE_LF   (1<<16)	/* Bare <LF> received */
-
  /*
   * These are set when we can't bounce even if we were asked to.
   */
